==> mysql-8.0_8.0.36.orig.tar.gz: mysql-8.0.36/router/src/harness/tests/test_net_ts_io_context_socket.cc <==
/*
  Copyright (c) 2019, 2023, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "mysql/harness/net_ts/internet.h"
#include "mysql/harness/net_ts/io_context.h"
#include "mysql/harness/net_ts/socket.h"

#include <gmock/gmock.h>

// net-ts 18.6.4:: 19.1
//
// cancel() an closed socket should result in bad-file-descriptor
TEST(NetTS_io_context, cancel_not_open_socket) {
  net::io_context io_ctx;

  net::ip::tcp::socket sock(io_ctx);

  EXPECT_FALSE(sock.is_open());

  EXPECT_EQ(sock.cancel(),
            stdx::make_unexpected(std::errc::bad_file_descriptor));
}

int main(int argc, char *argv[]) {
  ::testing::InitGoogleTest(&argc, argv);
  return RUN_ALL_TESTS();
}

==> mysql-8.0_8.0.44.orig.tar.gz: mysql-8.0.44/router/src/harness/tests/test_net_ts_io_context_socket.cc <==
/*
  Copyright (c) 2019, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "mysql/harness/net_ts/internet.h"
#include "mysql/harness/net_ts/io_context.h"
#include "mysql/harness/net_ts/socket.h"

#include <gmock/gmock.h>

// net-ts 18.6.4:: 19.1
//
// cancel() an closed socket should result in bad-file-descriptor
TEST(NetTS_io_context, cancel_not_open_socket) {
  net::io_context io_ctx;

  net::ip::tcp::socket sock(io_ctx);

  EXPECT_FALSE(sock.is_open());

  EXPECT_EQ(sock.cancel(),
            stdx::make_unexpected(std::errc::bad_file_descriptor));
}

int main(int argc, char *argv[]) {
  ::testing::InitGoogleTest(&argc, argv);
  return RUN_ALL_TESTS();
}
